<div aria-hidden="true" class="side-menu-toggle inverted medium icon mr-0" title="{{_('Toggle side menu')}}">
  <i class="inverted chevron left icon mr-0" aria-hidden="true"></i>
  <i class="inverted chevron right icon hidden mr-0" aria-hidden="true"></i>
</div>
