{#
  Copyright (C) 2020 CERN.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- from "invenio_administration/macros.html" import go_back %}

{% extends admin_base_template %}

{% block page_title %}
  {{ go_back() }}

{% endblock page_title %}

{% block admin_page_content %}
  <div
    id='invenio-details-config'
    data-actions='{{ actions | tojson }}'
    data-api-endpoint='{{ api_endpoint }}'
    data-display-delete='{{ display_delete | tojson }}'
    data-display-edit='{{ display_edit | tojson }}'
    data-exclude-fields='{{ exclude_fields | tojson }}'
    data-fields='{{ fields | tojson }}'
    data-pid='{{ pid | tojson }}'
    data-resource-schema='{{ resource_schema | tojson }}'
    data-ui-config='{{ ui_config | tojson }}'
    data-title='{{ title or name | tojson }}'
    data-list-endpoint='{{ list_ui_endpoint }}'
    data-resource-name='{{ resource_name | tojson }}'
    data-pid-path='{{ pid_path | tojson }}'
    data-request-headers='{{ request_headers | tojson }}'
  >
  </div>
{% endblock admin_page_content %}

{% block javascript %}
  {{ super() }}
  {{ webpack['invenio-administration-details.js'] }}
{% endblock %}
