{#
  Copyright (C) 2020 CERN.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- from "invenio_administration/macros.html" import go_back %}

{% extends admin_base_template %}

{% block page_title %}
  {{ go_back() }}
  <h1>{{ title or name }}</h1>
  <div class="ui divider" aria-hidden="true"></div>
{% endblock page_title %}

{% block admin_page_content %}
  <div
    id="invenio-administration-edit-root"
    data-api-endpoint='{{ api_endpoint }}'
    data-pid='{{ pid | tojson }}'
    data-resource-schema='{{ resource_schema | tojson }}'
    data-form-fields='{{ form_fields | tojson }}'
    data-referrer="{{ request.referrer }}"
    data-list-endpoint='{{ list_endpoint }}'
  >
  </div>
{% endblock admin_page_content %}

{% block javascript %}
  {{ super() }}
  {{ webpack['invenio-administration-edit.js'] }}
{% endblock %}
